@@ -1,51 +1,31 @@
-"""Undersampling-based Online Bagging."""
-
 import numpy as np
-from sklearn.base import ClassifierMixin, clone
-from sklearn.ensemble import BaseEnsemble
-from sklearn.utils.validation import check_array, check_is_fitted, check_X_y
+from sklearn.base import clone
+from ..ensembles.base import StreamingEnsemble
 
-
-class UOB(BaseEnsemble, ClassifierMixin):
+class UOB(StreamingEnsemble):
     """
     Undersampling-Based Online Bagging.
     """
-
     def __init__(self, base_estimator=None, n_estimators=5, time_decay_factor=0.9):
         """Initialization."""
-        self.base_estimator = base_estimator
-        self.n_estimators = n_estimators
+        super().__init__(base_estimator, n_estimators)
         self.time_decay_factor = time_decay_factor
 
-    def fit(self, X, y):
-        """Fitting."""
-        self.partial_fit(X, y)
-        return self
-
     def partial_fit(self, X, y, classes=None):
-        """Partial fitting."""
-        X, y = check_X_y(X, y)
-        if not hasattr(self, "ensemble_"):
+        super().partial_fit(X, y, classes)
+        if not self.green_light:
+            return self
+
+        if len(self.ensemble_) == 0:
             self.ensemble_ = [
                 clone(self.base_estimator) for i in range(self.n_estimators)
             ]
 
-        # Check feature consistency
-        if hasattr(self, "X_"):
-            if self.X_.shape[1] != X.shape[1]:
-                raise ValueError("number of features does not match")
-        self.X_, self.y_ = X, y
-
-        # Check classes
-        self.classes_ = classes
-        if self.classes_ is None:
-            self.classes_, _ = np.unique(y, return_inverse=True)
-
         # time decayed class sizes tracking
         if not hasattr(self, "last_instance_sizes"):
             self.current_tdcs_ = np.zeros((1, 2))
         else:
-            self.current_ctdcs_ = self.last_instance_sizes
+            self.current_tdcs_ = self.last_instance_sizes
 
         self.chunk_tdcs = np.ones((self.X_.shape[0], self.classes_.shape[0]))
 
@@ -108,31 +88,3 @@ class UOB(BaseEnsemble, ClassifierMixin):
             )
 
         return self
-
-    def ensemble_support_matrix(self, X):
-        """Ensemble support matrix."""
-        return np.array([member_clf.predict_proba(X) for member_clf in self.ensemble_])
-
-    def predict(self, X):
-        """
-        Predict classes for X.
-
-        :type X: array-like, shape (n_samples, n_features)
-        :param X: The training input samples.
-
-        :rtype: array-like, shape (n_samples, )
-        :returns: The predicted classes.
-        """
-
-        # Check is fit had been called
-        check_is_fitted(self, "classes_")
-        X = check_array(X)
-        if X.shape[1] != self.X_.shape[1]:
-            raise ValueError("number of features does not match")
-
-        esm = self.ensemble_support_matrix(X)
-        average_support = np.mean(esm, axis=0)
-        prediction = np.argmax(average_support, axis=1)
-
-        # Return prediction
-        return self.classes_[prediction]
