@@ -1,15 +1,10 @@
-"""
-Weighted Aging Ensemble.
-
-"""
+"""Weighted Aging Ensemble."""
 
 import numpy as np
 from sklearn import base
-from sklearn.base import ClassifierMixin
-from sklearn.ensemble import BaseEnsemble
 from sklearn.utils.multiclass import _check_partial_fit_first_call
 from sklearn.utils.validation import check_array, check_is_fitted, check_X_y
-
+from ..ensembles.base import StreamingEnsemble
 from ..ensembles import pruning
 
 WEIGHT_CALCULATION = (
@@ -22,10 +17,56 @@ WEIGHT_CALCULATION = (
 
 AGING_METHOD = ("weights_proportional", "constant", "gaussian")
 
-
-class WAE(BaseEnsemble, ClassifierMixin):
+class WAE(StreamingEnsemble):
     """
     Weighted Aging Ensemble.
+
+    The method was inspired by Accuracy Weighted Ensemble (AWE) algorithm to which it introduces two main modifications: (I) classifier weights depend on the individual classifier accuracies and time they have been spending in the ensemble, (II) individual classifier are chosen on the basis on the non-pairwise diversity measure.
+
+    :type base_estimator: ClassifierMixin class object
+    :param base_estimator: Classification algorithm used as a base estimator.
+    :type n_estimators: integer, optional (default=10)
+    :param  n_estimators: The maximum number of estimators trained using consecutive data chunks and maintained in the ensemble.
+    :type theta: float, optional (default=0.1)
+    :param theta: Threshold for weight calculation method and aging procedure control.
+    :type post_pruning: boolean, optional (default=False)
+    :param post_pruning: Whether the pruning is conducted before or after adding the classifier.
+    :type pruning_criterion: string, optional (default='accuracy')
+    :param pruning_criterion: Selection of pruning criterion.
+    :type weight_calculation_method: string, optional (default='kuncheva')
+    :param weight_calculation_method: same_for_each, proportional_to_accuracy, kuncheva, pta_related_to_whole, bell_curve,
+    :type aging_method: string, optional (default='weights_proportional')
+    :param aging_method: weights_proportional, constant, gaussian.
+    :type rejuvenation_power: float, optional (default=0.0)
+    :param rejuvenation_power: Rejuvenation dynamics control of classifiers with high prediction accuracy.
+
+    :vartype ensemble_: list of classifiers
+    :var ensemble_: The collection of fitted sub-estimators.
+    :vartype classes_: array-like, shape (n_classes, )
+    :var classes_: The class labels.
+    :vartype weights_: array-like, shape (n_estimators, )
+    :var weights_: Classifier weights.
+
+    :Examples:
+
+    >>> import strlearn as sl
+    >>> from sklearn.naive_bayes import GaussianNB
+    >>> stream = sl.streams.StreamGenerator()
+    >>> clf = sl.ensembles.WAE(GaussianNB())
+    >>> ttt = sl.evaluators.TestThenTrain(
+    >>> metrics=(sl.metrics.balanced_accuracy_score))
+    >>> ttt.process(stream, clf)
+    >>> print(ttt.scores)
+    [[[0.91386218]
+      [0.93032581]
+      [0.90907219]
+      [0.90544872]
+      [0.90466186]
+      [0.91956783]
+      [0.90776942]
+      [0.92685422]
+      [0.92895186]
+      ...
     """
 
     def __init__(
@@ -40,9 +81,8 @@ class WAE(BaseEnsemble, ClassifierMixin):
         rejuvenation_power=0.0,
     ):
         """Initialization."""
-        self.base_estimator = base_estimator
+        super().__init__(base_estimator, n_estimators, weighted=True)
         self.pruning_criterion = pruning_criterion
-        self.n_estimators = n_estimators
         self.theta = theta
         self.post_pruning = post_pruning
         self.weight_calculation_method = weight_calculation_method
@@ -61,40 +101,18 @@ class WAE(BaseEnsemble, ClassifierMixin):
         self.iterations_ = self.iterations_[combination]
         self.weights_ = self.weights_[combination]
 
-    # Fitting
-    def fit(self, X, y):
-        """Fitting."""
-        X, y = check_X_y(X, y)
-        self.X_ = X
-        self.y_ = y
-
-        candidate_clf = base.clone(self.base_estimator)
-        candidate_clf.fit(X, y)
-
-        self.ensemble_ = [candidate_clf]
-        self.weights_ = np.array([1])
-        self.classes_, _ = np.unique(y, return_inverse=True)
-        self.age_ = 0
-        self.iterations_ = np.array([])
-
-        # Return the classifier
-        return self
-
     def partial_fit(self, X, y, classes=None):
-        """Partial fitting."""
-        X, y = check_X_y(X, y)
-        self.X_ = X
-        self.y_ = y
+        # Initialization
+        super().partial_fit(X, y, classes)
+        if not self.green_light:
+            return self
 
-        if _check_partial_fit_first_call(self, classes):
-            self.classes_ = classes
-
-            self.ensemble_ = []
+        if len(self.ensemble_) == 0:
             self.weights_ = np.array([1])
             self.age_ = 0
             self.iterations_ = np.array([])
 
-        """Partial fitting"""
+        # Scoring
         if self.age_ > 0:
             self.overall_accuracy = self.score(
                 self.previous_X, self.previous_y)
@@ -104,7 +122,6 @@ class WAE(BaseEnsemble, ClassifierMixin):
             self._prune()
 
         # Preparing and training new candidate
-        self.classes_ = classes
         candidate_clf = base.clone(self.base_estimator)
         candidate_clf.fit(X, y)
         self.ensemble_.append(candidate_clf)
@@ -185,51 +202,8 @@ class WAE(BaseEnsemble, ClassifierMixin):
             self.iterations_[mask] -= self.rejuvenation_power * (
                 self.weights_[mask] - w
             )
-            # TODO do przemyslenia
 
     def _extinct(self):
         combination = np.array(np.where(self.weights_ > 0))[0]
         if len(combination) > 0:
             self._filter_ensemble(combination)
-
-    def ensemble_support_matrix(self, X):
-        """ESM."""
-        return np.array([member_clf.predict_proba(X) for member_clf in self.ensemble_])
-
-    def predict_proba(self, X):
-        """Aposteriori probabilities."""
-        # Check is fit had been called
-        check_is_fitted(self, "classes_")
-
-        # Weight support before acumulation
-        weighted_support = (
-            self.ensemble_support_matrix(
-                X) * self.weights_[:, np.newaxis, np.newaxis]
-        )
-
-        # Acumulate supports
-        acumulated_weighted_support = np.sum(weighted_support, axis=0)
-        return acumulated_weighted_support
-
-    def predict(self, X):
-        """
-        Predict classes for X.
-
-        :type X: array-like, shape (n_samples, n_features)
-        :param X: The training input samples.
-
-        :rtype: array-like, shape (n_samples, )
-        :returns: The predicted classes.
-        """
-        # Check is fit had been called
-        check_is_fitted(self, "classes_")
-
-        # Input validation
-        X = check_array(X)
-        if X.shape[1] != self.X_.shape[1]:
-            raise ValueError("number of features does not match")
-
-        supports = self.predict_proba(X)
-        prediction = np.argmax(supports, axis=1)
-
-        return self.classes_[prediction]
