@@ -8,9 +8,11 @@ from .UOB import UOB
 from .DWM import DWM
 from .REA import REA
 from .KMC import KMC
-from .learnppCDS import LearnppCDS
-from .learnppNIE import LearnppNIE
+from .CDS import CDS
+from .NIE import NIE
 from .OUSE import OUSE
+from .KUE import KUE
+from .base import StreamingEnsemble
 
 __all__ = [
     "OnlineBagging",
@@ -23,7 +25,9 @@ __all__ = [
     "DWM",
     "REA",
     "KMC",
-    "LearnppCDS",
-    "LearnppNIE",
-    "OUSE"
+    "CDS",
+    "NIE",
+    "OUSE",
+    "KUE",
+    "StreamingEnsemble"
 ]
