@@ -1,4 +1,4 @@
-from .metrics import (balanced_accuracy_score, binary_confusion_matrix,
+from .base import (balanced_accuracy_score, binary_confusion_matrix,
                       f1_score, fbeta_score, geometric_mean_score_1,
                       geometric_mean_score_2, precision, recall, specificity)
 
