@@ -21,8 +21,8 @@ def get_clfs():
         sl.ensembles.OnlineBagging(GaussianNB()),
         sl.ensembles.REA(GaussianNB()),
         sl.ensembles.KMC(GaussianNB()),
-        sl.ensembles.LearnppCDS(GaussianNB()),
-        sl.ensembles.LearnppNIE(GaussianNB()),
+        sl.ensembles.CDS(GaussianNB()),
+        sl.ensembles.NIE(GaussianNB()),
         sl.ensembles.OUSE(GaussianNB())
     ]
 
@@ -36,8 +36,7 @@ def get_different_stream():
 
 
 def get_imbalanced_stream():
-    return sl.streams.StreamGenerator(n_chunks=2, n_features=10, weights=[0.99,0.01])
-
+    return sl.streams.StreamGenerator(n_chunks=2, n_features=10, weights=[0.99,0.01], random_state=1410)
 
 def test_predict_proba():
     clfs = get_clfs()
@@ -47,13 +46,13 @@ def test_predict_proba():
     for clf in clfs:
         if hasattr(clf, "predict_proba"):
             clf.fit(X, y)
+            print("CLF", clf)
             pp = clf.predict_proba(X)
             y_pred = clf.predict(X)
             y_pred_pp = np.argmax(pp, axis=1)
 
             assert np.array_equal(y_pred, y_pred_pp)
 
-
 def test_ensembles_fit():
     clfs = get_clfs()
     stream = get_stream()
@@ -107,27 +106,16 @@ def test_minority_majority_name_split():
             clf.fit(X, y)
 
 
-def test_one_class():
-    clfs = get_clfs()
-    stream = get_imbalanced_stream()
-    X, y = stream.get_chunk()
-
-    minority_ma = np.ma.masked_where(y == 0, y)
-    X = X[minority_ma.mask]
-    y = y[minority_ma.mask]
-
-
-    for clf in clfs:
-        if hasattr(clf, "minority_majority_name"):
-            with pytest.raises(ValueError):
-                clf.fit(X, y)
-
-
 def test_DWM():
     stream = get_stream()
     evaluator = sl.evaluators.TestThenTrain()
     evaluator.process(stream, sl.ensembles.DWM(GaussianNB(), p=stream.chunk_size))
 
+def test_KUE():
+    stream = get_stream()
+    evaluator = sl.evaluators.TestThenTrain()
+    evaluator.process(stream, sl.ensembles.KUE(GaussianNB(), n_estimators=5))
+
 
 def test_AWE():
     stream = get_stream()
@@ -274,13 +262,13 @@ def test_KMC():
 def test_learnppCDS():
     stream = get_stream()
     evaluator = sl.evaluators.TestThenTrain()
-    evaluator.process(stream, sl.ensembles.LearnppCDS(GaussianNB(), n_estimators=5))
+    evaluator.process(stream, sl.ensembles.CDS(GaussianNB(), n_estimators=5))
 
 
 def test_learnppNIE():
     stream = get_stream()
     evaluator = sl.evaluators.TestThenTrain()
-    evaluator.process(stream, sl.ensembles.LearnppNIE(GaussianNB(), n_estimators=5))
+    evaluator.process(stream, sl.ensembles.NIE(GaussianNB(), n_estimators=5))
 
 
 def test_OUSE():
